@@ -6,9 +6,9 @@ Type annotations for codestar-notifications service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_codestar_notifications.type_defs import CreateNotificationRuleRequestRequestTypeDef
+    from mypy_boto3_codestar_notifications.type_defs import TargetTypeDef
 
-    data: CreateNotificationRuleRequestRequestTypeDef = {...}
+    data: TargetTypeDef = {...}
     ```
 """
 import sys
@@ -31,76 +31,60 @@ else:
 
 
 __all__ = (
-    "CreateNotificationRuleRequestRequestTypeDef",
-    "CreateNotificationRuleResultTypeDef",
+    "TargetTypeDef",
+    "ResponseMetadataTypeDef",
     "DeleteNotificationRuleRequestRequestTypeDef",
-    "DeleteNotificationRuleResultTypeDef",
     "DeleteTargetRequestRequestTypeDef",
     "DescribeNotificationRuleRequestRequestTypeDef",
-    "DescribeNotificationRuleResultTypeDef",
     "EventTypeSummaryTypeDef",
+    "TargetSummaryTypeDef",
     "ListEventTypesFilterTypeDef",
-    "ListEventTypesRequestListEventTypesPaginateTypeDef",
-    "ListEventTypesRequestRequestTypeDef",
-    "ListEventTypesResultTypeDef",
+    "PaginatorConfigTypeDef",
     "ListNotificationRulesFilterTypeDef",
+    "NotificationRuleSummaryTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTargetsFilterTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "UnsubscribeRequestRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "CreateNotificationRuleRequestRequestTypeDef",
+    "SubscribeRequestRequestTypeDef",
+    "UpdateNotificationRuleRequestRequestTypeDef",
+    "CreateNotificationRuleResultTypeDef",
+    "DeleteNotificationRuleResultTypeDef",
+    "ListTagsForResourceResultTypeDef",
+    "SubscribeResultTypeDef",
+    "TagResourceResultTypeDef",
+    "UnsubscribeResultTypeDef",
+    "ListEventTypesResultTypeDef",
+    "DescribeNotificationRuleResultTypeDef",
+    "ListTargetsResultTypeDef",
+    "ListEventTypesRequestRequestTypeDef",
+    "ListEventTypesRequestListEventTypesPaginateTypeDef",
     "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
     "ListNotificationRulesRequestRequestTypeDef",
     "ListNotificationRulesResultTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResultTypeDef",
-    "ListTargetsFilterTypeDef",
     "ListTargetsRequestListTargetsPaginateTypeDef",
     "ListTargetsRequestRequestTypeDef",
-    "ListTargetsResultTypeDef",
-    "NotificationRuleSummaryTypeDef",
-    "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "SubscribeRequestRequestTypeDef",
-    "SubscribeResultTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "TagResourceResultTypeDef",
-    "TargetSummaryTypeDef",
-    "TargetTypeDef",
-    "UnsubscribeRequestRequestTypeDef",
-    "UnsubscribeResultTypeDef",
-    "UntagResourceRequestRequestTypeDef",
-    "UpdateNotificationRuleRequestRequestTypeDef",
 )
 
-_RequiredCreateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateNotificationRuleRequestRequestTypeDef",
+TargetTypeDef = TypedDict(
+    "TargetTypeDef",
     {
-        "Name": str,
-        "EventTypeIds": Sequence[str],
-        "Resource": str,
-        "Targets": Sequence["TargetTypeDef"],
-        "DetailType": DetailTypeType,
-    },
-)
-_OptionalCreateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateNotificationRuleRequestRequestTypeDef",
-    {
-        "ClientRequestToken": str,
-        "Tags": Mapping[str, str],
-        "Status": NotificationRuleStatusType,
+        "TargetType": str,
+        "TargetAddress": str,
     },
     total=False,
 )
 
-
-class CreateNotificationRuleRequestRequestTypeDef(
-    _RequiredCreateNotificationRuleRequestRequestTypeDef,
-    _OptionalCreateNotificationRuleRequestRequestTypeDef,
-):
-    pass
-
-
-CreateNotificationRuleResultTypeDef = TypedDict(
-    "CreateNotificationRuleResultTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "Arn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -111,14 +95,6 @@ DeleteNotificationRuleRequestRequestTypeDef = TypedDict(
     },
 )
 
-DeleteNotificationRuleResultTypeDef = TypedDict(
-    "DeleteNotificationRuleResultTypeDef",
-    {
-        "Arn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredDeleteTargetRequestRequestTypeDef = TypedDict(
     "_RequiredDeleteTargetRequestRequestTypeDef",
     {
@@ -147,24 +123,6 @@ DescribeNotificationRuleRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeNotificationRuleResultTypeDef = TypedDict(
-    "DescribeNotificationRuleResultTypeDef",
-    {
-        "Arn": str,
-        "Name": str,
-        "EventTypes": List["EventTypeSummaryTypeDef"],
-        "Resource": str,
-        "Targets": List["TargetSummaryTypeDef"],
-        "DetailType": DetailTypeType,
-        "CreatedBy": str,
-        "Status": NotificationRuleStatusType,
-        "CreatedTimestamp": datetime,
-        "LastModifiedTimestamp": datetime,
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 EventTypeSummaryTypeDef = TypedDict(
     "EventTypeSummaryTypeDef",
     {
@@ -176,6 +134,16 @@ EventTypeSummaryTypeDef = TypedDict(
     total=False,
 )
 
+TargetSummaryTypeDef = TypedDict(
+    "TargetSummaryTypeDef",
+    {
+        "TargetAddress": str,
+        "TargetType": str,
+        "TargetStatus": TargetStatusType,
+    },
+    total=False,
+)
+
 ListEventTypesFilterTypeDef = TypedDict(
     "ListEventTypesFilterTypeDef",
     {
@@ -184,34 +152,16 @@ ListEventTypesFilterTypeDef = TypedDict(
     },
 )
 
-ListEventTypesRequestListEventTypesPaginateTypeDef = TypedDict(
-    "ListEventTypesRequestListEventTypesPaginateTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "Filters": Sequence["ListEventTypesFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-ListEventTypesRequestRequestTypeDef = TypedDict(
-    "ListEventTypesRequestRequestTypeDef",
-    {
-        "Filters": Sequence["ListEventTypesFilterTypeDef"],
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListEventTypesResultTypeDef = TypedDict(
-    "ListEventTypesResultTypeDef",
-    {
-        "EventTypes": List["EventTypeSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListNotificationRulesFilterTypeDef = TypedDict(
     "ListNotificationRulesFilterTypeDef",
     {
@@ -220,85 +170,6 @@ ListNotificationRulesFilterTypeDef = TypedDict(
     },
 )
 
-ListNotificationRulesRequestListNotificationRulesPaginateTypeDef = TypedDict(
-    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
-    {
-        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListNotificationRulesRequestRequestTypeDef = TypedDict(
-    "ListNotificationRulesRequestRequestTypeDef",
-    {
-        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListNotificationRulesResultTypeDef = TypedDict(
-    "ListNotificationRulesResultTypeDef",
-    {
-        "NextToken": str,
-        "NotificationRules": List["NotificationRuleSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "Arn": str,
-    },
-)
-
-ListTagsForResourceResultTypeDef = TypedDict(
-    "ListTagsForResourceResultTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTargetsFilterTypeDef = TypedDict(
-    "ListTargetsFilterTypeDef",
-    {
-        "Name": ListTargetsFilterNameType,
-        "Value": str,
-    },
-)
-
-ListTargetsRequestListTargetsPaginateTypeDef = TypedDict(
-    "ListTargetsRequestListTargetsPaginateTypeDef",
-    {
-        "Filters": Sequence["ListTargetsFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListTargetsRequestRequestTypeDef = TypedDict(
-    "ListTargetsRequestRequestTypeDef",
-    {
-        "Filters": Sequence["ListTargetsFilterTypeDef"],
-        "NextToken": str,
-        "MaxResults": int,
-    },
-    total=False,
-)
-
-ListTargetsResultTypeDef = TypedDict(
-    "ListTargetsResultTypeDef",
-    {
-        "Targets": List["TargetSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 NotificationRuleSummaryTypeDef = TypedDict(
     "NotificationRuleSummaryTypeDef",
     {
@@ -308,32 +179,78 @@ NotificationRuleSummaryTypeDef = TypedDict(
     total=False,
 )
 
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "Arn": str,
+    },
+)
+
+ListTargetsFilterTypeDef = TypedDict(
+    "ListTargetsFilterTypeDef",
+    {
+        "Name": ListTargetsFilterNameType,
+        "Value": str,
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "Arn": str,
+        "Tags": Mapping[str, str],
+    },
+)
+
+UnsubscribeRequestRequestTypeDef = TypedDict(
+    "UnsubscribeRequestRequestTypeDef",
+    {
+        "Arn": str,
+        "TargetAddress": str,
+    },
+)
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "Arn": str,
+        "TagKeys": Sequence[str],
+    },
+)
+
+_RequiredCreateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateNotificationRuleRequestRequestTypeDef",
+    {
+        "Name": str,
+        "EventTypeIds": Sequence[str],
+        "Resource": str,
+        "Targets": Sequence[TargetTypeDef],
+        "DetailType": DetailTypeType,
+    },
+)
+_OptionalCreateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateNotificationRuleRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "Tags": Mapping[str, str],
+        "Status": NotificationRuleStatusType,
     },
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
+
+class CreateNotificationRuleRequestRequestTypeDef(
+    _RequiredCreateNotificationRuleRequestRequestTypeDef,
+    _OptionalCreateNotificationRuleRequestRequestTypeDef,
+):
+    pass
+
 
 _RequiredSubscribeRequestRequestTypeDef = TypedDict(
     "_RequiredSubscribeRequestRequestTypeDef",
     {
         "Arn": str,
-        "Target": "TargetTypeDef",
+        "Target": TargetTypeDef,
     },
 )
 _OptionalSubscribeRequestRequestTypeDef = TypedDict(
@@ -351,73 +268,6 @@ class SubscribeRequestRequestTypeDef(
     pass
 
 
-SubscribeResultTypeDef = TypedDict(
-    "SubscribeResultTypeDef",
-    {
-        "Arn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "Arn": str,
-        "Tags": Mapping[str, str],
-    },
-)
-
-TagResourceResultTypeDef = TypedDict(
-    "TagResourceResultTypeDef",
-    {
-        "Tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-TargetSummaryTypeDef = TypedDict(
-    "TargetSummaryTypeDef",
-    {
-        "TargetAddress": str,
-        "TargetType": str,
-        "TargetStatus": TargetStatusType,
-    },
-    total=False,
-)
-
-TargetTypeDef = TypedDict(
-    "TargetTypeDef",
-    {
-        "TargetType": str,
-        "TargetAddress": str,
-    },
-    total=False,
-)
-
-UnsubscribeRequestRequestTypeDef = TypedDict(
-    "UnsubscribeRequestRequestTypeDef",
-    {
-        "Arn": str,
-        "TargetAddress": str,
-    },
-)
-
-UnsubscribeResultTypeDef = TypedDict(
-    "UnsubscribeResultTypeDef",
-    {
-        "Arn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-UntagResourceRequestRequestTypeDef = TypedDict(
-    "UntagResourceRequestRequestTypeDef",
-    {
-        "Arn": str,
-        "TagKeys": Sequence[str],
-    },
-)
-
 _RequiredUpdateNotificationRuleRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateNotificationRuleRequestRequestTypeDef",
     {
@@ -430,7 +280,7 @@ _OptionalUpdateNotificationRuleRequestRequestTypeDef = TypedDict(
         "Name": str,
         "Status": NotificationRuleStatusType,
         "EventTypeIds": Sequence[str],
-        "Targets": Sequence["TargetTypeDef"],
+        "Targets": Sequence[TargetTypeDef],
         "DetailType": DetailTypeType,
     },
     total=False,
@@ -442,3 +292,154 @@ class UpdateNotificationRuleRequestRequestTypeDef(
     _OptionalUpdateNotificationRuleRequestRequestTypeDef,
 ):
     pass
+
+
+CreateNotificationRuleResultTypeDef = TypedDict(
+    "CreateNotificationRuleResultTypeDef",
+    {
+        "Arn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DeleteNotificationRuleResultTypeDef = TypedDict(
+    "DeleteNotificationRuleResultTypeDef",
+    {
+        "Arn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResultTypeDef = TypedDict(
+    "ListTagsForResourceResultTypeDef",
+    {
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SubscribeResultTypeDef = TypedDict(
+    "SubscribeResultTypeDef",
+    {
+        "Arn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TagResourceResultTypeDef = TypedDict(
+    "TagResourceResultTypeDef",
+    {
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UnsubscribeResultTypeDef = TypedDict(
+    "UnsubscribeResultTypeDef",
+    {
+        "Arn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListEventTypesResultTypeDef = TypedDict(
+    "ListEventTypesResultTypeDef",
+    {
+        "EventTypes": List[EventTypeSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeNotificationRuleResultTypeDef = TypedDict(
+    "DescribeNotificationRuleResultTypeDef",
+    {
+        "Arn": str,
+        "Name": str,
+        "EventTypes": List[EventTypeSummaryTypeDef],
+        "Resource": str,
+        "Targets": List[TargetSummaryTypeDef],
+        "DetailType": DetailTypeType,
+        "CreatedBy": str,
+        "Status": NotificationRuleStatusType,
+        "CreatedTimestamp": datetime,
+        "LastModifiedTimestamp": datetime,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTargetsResultTypeDef = TypedDict(
+    "ListTargetsResultTypeDef",
+    {
+        "Targets": List[TargetSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListEventTypesRequestRequestTypeDef = TypedDict(
+    "ListEventTypesRequestRequestTypeDef",
+    {
+        "Filters": Sequence[ListEventTypesFilterTypeDef],
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListEventTypesRequestListEventTypesPaginateTypeDef = TypedDict(
+    "ListEventTypesRequestListEventTypesPaginateTypeDef",
+    {
+        "Filters": Sequence[ListEventTypesFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListNotificationRulesRequestListNotificationRulesPaginateTypeDef = TypedDict(
+    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
+    {
+        "Filters": Sequence[ListNotificationRulesFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListNotificationRulesRequestRequestTypeDef = TypedDict(
+    "ListNotificationRulesRequestRequestTypeDef",
+    {
+        "Filters": Sequence[ListNotificationRulesFilterTypeDef],
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListNotificationRulesResultTypeDef = TypedDict(
+    "ListNotificationRulesResultTypeDef",
+    {
+        "NextToken": str,
+        "NotificationRules": List[NotificationRuleSummaryTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTargetsRequestListTargetsPaginateTypeDef = TypedDict(
+    "ListTargetsRequestListTargetsPaginateTypeDef",
+    {
+        "Filters": Sequence[ListTargetsFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListTargetsRequestRequestTypeDef = TypedDict(
+    "ListTargetsRequestRequestTypeDef",
+    {
+        "Filters": Sequence[ListTargetsFilterTypeDef],
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
